"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FileCache = void 0;
/**
 * A cache of whether file information, to save redundant disk I/O.
 */
class FileCache {
    constructor(timeout) {
        this.#cache = new Map();
        this.#timeout = timeout;
    }
    #cache;
    #timeout;
    /**
     * Adds a file to the cache
     */
    add(file) {
        this.addPending(file.absolutePath, Promise.resolve(file));
    }
    /**
     * Adds a file to the cache while its info is being read from disk
     */
    addPending(absolutePath, promise) {
        const cached = promise.then(file => ({
            ...file,
            expires: Date.now() + this.#timeout,
        }));
        this.#cache.set(absolutePath, cached);
    }
    /**
     * Removes a file from the cache
     */
    remove(absolutePath) {
        this.#cache.delete(absolutePath);
    }
    /**
     * Removes a file from the cache
     */
    async get(absolutePath) {
        const cached = this.#cache.get(absolutePath);
        if (cached) {
            return cached;
        }
        else {
            return {
                absolutePath,
                exists: false,
                expires: 0,
            };
        }
    }
}
exports.FileCache = FileCache;
//# sourceMappingURL=file-cache.js.map