"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.nextMDX = void 0;
const officialNextMDX = require("@next/mdx");
const path = require("path");
const frontmatter = require("remark-frontmatter");
const annotate_markdown_nodes_1 = require("./annotate-markdown-nodes");
const frontmatter_to_mdx_1 = require("./frontmatter-to-mdx");
const link_to_mdx_1 = require("./link-to-mdx");
const options_1 = require("./options");
const sitemap_1 = require("./sitemap");
require("./typings");
/**
 * Adds support for MDX with advanced syntax features in Next.js applications
 */
function nextMDX(options = {}) {
    const opt = options_1.normalizeOptions(options);
    // Resolve directory paths to absolute paths
    opt.layoutsDir = path.resolve(opt.layoutsDir);
    opt.pagesDir = path.resolve(opt.pagesDir);
    // Start generating the sitemap.xml file, even before any MDX files are processed.
    // This ensures the sitemap gets generated, even in local dev mode.
    sitemap_1.generateSitemap(opt);
    // Call the official Next.js MDX plugin with our custom options
    return officialNextMDX({
        options: {
            remarkPlugins: [
                sitemap_1.awaitSitemap,
                frontmatter,
                [frontmatter_to_mdx_1.frontmatterToMDX, opt],
                [link_to_mdx_1.linkToMDX, opt],
            ],
            rehypePlugins: [
                [annotate_markdown_nodes_1.annotateMarkdownNodes, opt],
            ]
        }
    });
}
exports.nextMDX = nextMDX;
//# sourceMappingURL=next-mdx.js.map