"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeOptions = void 0;
const file_cache_1 = require("./file-cache");
/**
 * Normalizes user-specified options, and applies defaults for any options that
 * aren't specified.
 */
function normalizeOptions(options) {
    const fileCacheTimeout = options.fileCacheTimeout || 60000;
    if (!options.siteURL) {
        // We can only generate a sitemap if a siteURL is provided
        options.sitemap = false;
        options.siteURL = "http://localhost:3000";
    }
    return {
        defaultLayout: options.defaultLayout || "docs",
        layoutsDir: options.layoutsDir || "./layouts",
        pagesDir: options.pagesDir || "./pages",
        markdownPropName: options.markdownPropName || "markdown",
        markdownPropValue: options.markdownPropValue || true,
        sitemap: options.sitemap === false ? false : (options.sitemap || "./public/sitemap.xml"),
        siteURL: options.siteURL instanceof URL ? options.siteURL : new URL(options.siteURL),
        fileCache: new file_cache_1.FileCache(fileCacheTimeout),
    };
}
exports.normalizeOptions = normalizeOptions;
//# sourceMappingURL=options.js.map